@@ -562,6 +562,8 @@ func TestContexts(t *testing.T) {
 		{"matrix.os", "Linux", "matrix-context"},
 		{"needs.job-id.outputs.output-name", "value", "needs-context"},
 		{"needs.job-id.result", "success", "needs-context"},
+		{"contains(needs.*.result, 'success')", true, "needs-wildcard-context-contains-success"},
+		{"contains(needs.*.result, 'failure')", false, "needs-wildcard-context-contains-failure"},
 		{"inputs.name", "value", "inputs-context"},
 	}
 
@@ -610,6 +612,12 @@ func TestContexts(t *testing.T) {
 				},
 				Result: "success",
 			},
+			"another-job-id": {
+				Outputs: map[string]string{
+					"output-name": "value",
+				},
+				Result: "success",
+			},
 		},
 		Inputs: map[string]interface{}{
 			"name": "value",
